==> bizext.php7.0.zip: bizext/lib/spout/Reader/SheetInterface.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPznQvvpUeTlJ4+nol/rPZ0ykR7X98HXq9lW7zl6jZ2WSY4TGSVO32enxNTWayYyBuchUC4Ok
LhVFFIFbSt7AFrORV13xlwt7AHXsP6plOH6xWO4mK6GkrQxS9VS6R0y49SEOs16jwM/hM0PQakQr
9uScksHR9wZ+LCya9X0tPUM+PTUKAbA2HupSVq2WkBG689Z1rMkFVA4smtw70uVFlrWsOyOqim1w
fTYrkqrZmjymugQwhpNrM4l4pRhyh6huQVUv6gqKWTZ8B66BGzoIh0YBUXATO/e8YXK6y/AYI/bt
QLY5gIyi/2XGH3bf1IEdi3sd4KDG7ecLQ17M/eGSIbNOuE/+x6oJ8UaAfCHMOtUzehaApGBWV7kI
0KWIc8HI6e9xC3yP2WO7+nAFv6ctUNsuwmC1iyEwA1bC6Cn0Zhj1cLb/2AU9CH25AAtghzxu+gTX
9OmWPGOSFrbHins5XcFV1xSIzEYxtd/yGwx4DqB/vmWUz6MWRKc223O9RLFj0ZZPyAbTDtfONR9p
jShT3u6Nv68cG59c8hhPgi7Dqz+A/3dKHdVfqWGUer1dCkw+gDJ9Um62E/EjBNO6PuHsO1eWo33z
MXU+yekNGgMj2XROwyGw6fgg0bV9/TiWEJ+hY+oTfXMOj6i+gzw0uFyR1AfFMGmiCIfIh/6VEzqo
jfPeV5iSaWqL9och4bR+SDBmog1gWrCDpz8UYAO0YKAjnY5IRgZVMQw2gzKM3BNIWkV8MY8VoCX/
r3GmunUPen5a5K9/8CaH+49SwqEKVeKMSKrV26HyCqoQC9dKyd73BS42QyM1SZgGku3qpG3qfCuu
pCTJIouIaQqbKhaqEk3iLZgsIZI0TpL/XQN1UEjoELiV0hJvWbqWlP0ep/ZpTdgAMs1YwoApc6Z4
1PUb+ahhBUyE+yJpnh90ktoscFRbQ3Psi8AH1YKiAu6A59rMnyyT/l/t1R1ZKw5Fj2v7ARNl0kBz
SaZoE3SMB1XLXemDMRtRgc3Sw1bkpbCY2tqMv69N0qjZ90F4rHosrQdXQJwX4/xmz4vbMUXMTQP+
k3Jr6+016AH5ZGVcQp/XfxDqrRoWTw6YA59cehcsbNL1Tesw0UnP0zyZY6wO3HrCOpsoX1q3VcQR
gQF3/P2ukA8iwmnhbztwbis+xxcj4XPk

==> bizext.php7.1.zip: bizext/lib/spout/Reader/SheetInterface.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPz5xyquZmyTXZivcRIJZk6nSOA9hH1deFdcHYg5tKHOesi17A9vPGzhf2gjylVorI2GZjiNc
X54avWfSQbeNmOtzBtHIifNaY4h9q2FOcVnCFWOgyIeqAkwHrPTUtNYcmll1vl/a18jdzDNWYe7I
TfTo3AbqDQd8MfV68iyufKYSk8yugTfJzfl6fgCNQh1exH0Jf52qjTGHfA5NzWKHpsVt81Ifcxs5
L3as8DNiKhhCmeysiyjZL8N4ssMgHYg/NGnvo+OMNrpIUZAmvCf4MdwzcKj7wMM2a4mMhAT1cP3R
q4upWC7Gj4i6ry80YxbWNTbClRkISHDMAW5yWy2uAGN8ZuEUx2w1FnvBo9rARgwqxtxl1TZesZ5B
805vr2MSqZBGh9VmY4VLfPabW+06K54ESFYkXGx835zte8NonjPjvJ26fT6nOK8g+Ia30pzGjhh5
BZdkmb/RSLDXUYklFHQMGtdCmd8qsAiLN51zsxTPx3TRHAmPS9NdmI+218WW8hdnlKrJSRycfi3S
DLf/jem5amCAJ1oChMmqB7dhqTDkt5p2K2JvONQSASwDory8wP2VGp+7XGY7BnPbEdHhHEOA7Sfb
IzEWEqO34M6fkpMijhW5997bFXI/tJ1jGbp1FR1Kt8mcctbLtyJFbmoNZ5pprgb2qiNxpCsi76jC
Ght72ETYCBGx/jlO+OPYfdaXJw8/APOoKvgsUkhmu7Wz+zb2WSYUUxnpNDrtp+iB5N+MeYnSH5AP
0S15FNKs8vYGtQBuuFLeml/7zrIHQmXqkb3n8XIMNKEy8m3AOUPCiy4R69ymgwjhlJ6IxDXBb1Ie
+zpJ0pEBE/scqXNpKLyHViBoGw8rRnLzpt4mDXR2Wf1a4N/3mcPrkZt34f8XuGde4RpMNx9em5tx
o/tZn1ZL6zolEMw5qEJhX+dAI/vhaPH0r0SCpZlNhRLakOmUbPDOnSWorB5ShQ38qP9z
